@@ -1,14 +1,14 @@
 /* gc.h -- Functions for garbage collecting unused node contents.
-   $Id: gc.h,v 1.1.1.1 2003/12/06 01:32:41 karl Exp $
+   $Id: gc.h,v 1.3.2.1 2007/06/27 17:10:56 karl Exp $
 
    This file is part of GNU Info, a program for reading online documentation
    stored in Info format.
 
-   Copyright (C) 1993, 97 Free Software Foundation, Inc.
+   Copyright (C) 1993, 1997, 2004, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -28,10 +28,10 @@
 /* Add POINTER to the list of garbage collectible pointers.  A pointer
    is not actually garbage collected until no info window contains a node
    whose contents member is equal to the pointer. */
-extern void add_gcable_pointer ();
+extern void add_gcable_pointer (char *pointer);
 
 /* Grovel the list of info windows and gc-able pointers finding those
    node->contents which are collectible, and free them. */
-extern void gc_pointers ();
+extern void gc_pointers (void);
 
 #endif /* not INFO_GC_H */
