@@ -1,12 +1,12 @@
 /* signals.c -- install and maintain signal handlers.
-   $Id: signals.c,v 1.3 2004/03/14 00:57:30 karl Exp $
+   $Id: signals.c,v 1.7.2.1 2007/06/27 17:10:59 karl Exp $
 
-   Copyright (C) 1993, 1994, 1995, 1998, 2002, 2003, 2004 Free Software
+   Copyright (C) 1993, 1994, 1995, 1998, 2002, 2003, 2004, 2007 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 #include "signals.h"
@@ -34,8 +34,7 @@ void initialize_info_signal_handler (void);
 #if !defined (HAVE_SIGPROCMASK) && defined (HAVE_SIGSETMASK)
 /* Perform OPERATION on NEWSET, perhaps leaving information in OLDSET. */
 static void
-sigprocmask (operation, newset, oldset)
-     int operation, *newset, *oldset;
+sigprocmask (int operation, int *newset, int *oldset)
 {
   switch (operation)
     {
@@ -119,11 +118,15 @@ static signal_info old_QUIT;
 void
 initialize_info_signal_handler (void)
 {
-#if defined (HAVE_SIGACTION)
+#ifdef SA_NOCLDSTOP
+  /* (Based on info from Paul Eggert found in coreutils.)  Don't use
+     HAVE_SIGACTION to decide whether to use the sa_handler, sa_flags,
+     sa_mask members, as some systems (Solaris 7+) don't define them.  Use
+     SA_NOCLDSTOP instead; it's been part of POSIX.1 since day 1 (in 1988).  */
   info_signal_handler.sa_handler = info_signal_proc;
   info_signal_handler.sa_flags = 0;
   mask_termsig (&info_signal_handler.sa_mask);
-#endif /* HAVE_SIGACTION */
+#endif /* SA_NOCLDSTOP */
 
 #if defined (SIGTSTP)
   set_termsig (SIGTSTP, &old_TSTP);
