@@ -1,12 +1,12 @@
 /* html.c -- html-related utilities.
-   $Id: html.c,v 1.14 2004/02/28 12:46:50 dirt Exp $
+   $Id: html.c,v 1.28.2.1 2007/06/27 17:11:01 karl Exp $
 
-   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Free Software
+   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2007 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -308,12 +308,16 @@ rel=\"generator-home\" title=\"Texinfo Homepage\">\n");
     /* Since HTML doesn't have a sc element, we use span with a bit of
        CSS spice instead.  */
 #define CSS_FONT_SMALL_CAPS "font-variant:small-caps"
-    add_word_args ("  span.sc { %s }\n", CSS_FONT_SMALL_CAPS);
+    add_word_args ("  span.sc    { %s }\n", CSS_FONT_SMALL_CAPS);
 
-    /* Roman font class.  */
-#define CSS_FONT_ROMAN "font-family: serif; font-weight: normal;"
+    /* Roman (default) font class, closest we can come.  */
+#define CSS_FONT_ROMAN "font-family:serif; font-weight:normal;"
     add_word_args ("  span.roman { %s } \n", CSS_FONT_ROMAN);
 
+    /* Sans serif font class.  */
+#define CSS_FONT_SANSSERIF "font-family:sans-serif; font-weight:normal;"
+    add_word_args ("  span.sansserif { %s } \n", CSS_FONT_SANSSERIF);
+
     /* Write out any css code from the user's --css-file.  */
     if (css_inline)
       insert_string (css_inline);
@@ -337,14 +341,17 @@ rel=\"generator-home\" title=\"Texinfo Homepage\">\n");
 char *
 escape_string (char *string)
 {
-  int i=0, newlen=0;
-  char * newstring;
+  char *newstring;
+  int i = 0, newlen = 0;
 
   do
     {
       /* Find how much to allocate. */
       switch (string[i])
         {
+        case '"':
+          newlen += 6;          /* `&quot;' */
+          break;
         case '&':
           newlen += 5;          /* `&amp;' */
           break;
@@ -366,6 +373,10 @@ escape_string (char *string)
     {
       switch (string[i])
         {
+        case '"':
+          strcpy (newstring, "&quot;");
+          newstring += 6;
+          break;
         case '&':
           strcpy (newstring, "&amp;");
           newstring += 5;
@@ -482,9 +493,9 @@ void
 #if defined (VA_FPRINTF) && __STDC__
 insert_html_tag_with_attribute (int start_or_end, char *tag, char *format, ...)
 #else
-insert_html_tag_with_attribute (elt, arg, format, va_alist)
-     int arg;
-     char *elt;
+insert_html_tag_with_attribute (start_or_end, tag, format, va_alist)
+     int start_or_end;
+     char *tag;
      char *format;
      va_dcl
 #endif
@@ -580,31 +591,59 @@ add_link (char *nodename, char *attributes)
 }
 
 /* Output NAME with characters escaped as appropriate for an anchor
-   name, i.e., escape URL special characters as %<n>.  */
+   name, i.e., escape URL special characters with our _00hh convention
+   if OLD is zero.  (See the manual for details on the new scheme.)
+   
+   If OLD is nonzero, generate the node name with the 4.6-and-earlier
+   convention of %hh (and more special characters output as-is, notably
+   - and *).  This is only so that external references to old names can
+   still work with HTML generated by the new makeinfo; the gcc folks
+   needed this.  Our own HTML does not refer to these names.  */
+
 void
-add_escaped_anchor_name (char *name)
+add_escaped_anchor_name (char *name, int old)
 {
+  canon_white (name);
+
+  if (!old && !strchr ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ",
+                       *name))
+    { /* XHTML does not allow anything but an ASCII letter to start an
+         identifier.  Therefore kludge in this constant string if we
+         have a nonletter.  */
+      add_word ("g_t");
+    }
+
   for (; *name; name++)
     {
-      if (*name == '&')
-        add_word ("&amp;");
-      else if (! URL_SAFE_CHAR (*name))
+      if (cr_or_whitespace (*name))
+        add_char ('-');
+
+      else if (!old && !URL_SAFE_CHAR (*name))
         /* Cast so characters with the high bit set are treated as >128,
            for example o-umlaut should be 246, not -10.  */
+        add_word_args ("_00%x", (unsigned char) *name);
+
+      else if (old && !URL_SAFE_CHAR (*name) && !OLD_URL_SAFE_CHAR (*name))
+        /* Different output convention, but still cast as above.  */
         add_word_args ("%%%x", (unsigned char) *name);
+
       else
         add_char (*name);
     }
 }
 
 /* Insert the text for the name of a reference in an HTML anchor
-   appropriate for NODENAME.  If HREF is nonzero, it will be
-   appropriate for a href= attribute, rather than name= i.e., including
-   the `#' if it's an internal reference. */
+   appropriate for NODENAME.
+   
+   If HREF is zero, generate text for name= in the new node name
+     conversion convention.
+   If HREF is negative, generate text for name= in the old convention.
+   If HREF is positive, generate the name for an href= attribute, i.e.,
+     including the `#' if it's an internal reference.   */
 void
 add_anchor_name (char *nodename, int href)
 {
-  if (href)
+  if (href > 0)
     {
       if (splitting)
 	add_url_name (nodename, href);
@@ -617,8 +656,10 @@ add_anchor_name (char *nodename, int href)
   if (strcasecmp (nodename, "(dir)") == 0)
     /* Strip the parens, but keep the original letter-case.  */
     add_word_args ("%.3s", nodename + 1);
+  else if (strcasecmp (nodename, "top") == 0)
+    add_word ("Top");
   else
-    add_escaped_anchor_name (nodename);
+    add_escaped_anchor_name (nodename, href < 0);
 }
 
 /* Insert the text for the name of a reference in an HTML url, aprropriate
@@ -629,23 +670,38 @@ add_url_name (char *nodename, int href)
     add_nodename_to_filename (nodename, href);
 }
 
-/* Only allow [-0-9a-zA-Z_.] when nodifying filenames.  This may
-   result in filename clashes; e.g.,
-
-   @node Foo ],,,
-   @node Foo [,,,
-
-   both map to Foo--.html.  If that happens, cm_node will put all
-   the nodes whose file names clash on the same file.  */
+/* Convert non [A-Za-z0-9] to _00xx, where xx means the hexadecimal
+   representation of the ASCII character.  Also convert spaces and
+   newlines to dashes.  */
 static void
 fix_filename (char *filename)
 {
-  char *p;
-  for (p = filename; *p; p++)
+  int i;
+  int len = strlen (filename);
+  char *oldname = xstrdup (filename);
+
+  *filename = '\0';
+
+  for (i = 0; i < len; i++)
     {
-      if (!(isalnum (*p) || strchr ("-._", *p)))
-	*p = '-';
+      if (cr_or_whitespace (oldname[i]))
+        strcat (filename, "-");
+      else if (URL_SAFE_CHAR (oldname[i]))
+        strncat (filename, (char *) oldname + i, 1);
+      else
+        {
+          char *hexchar = xmalloc (6 * sizeof (char));
+          sprintf (hexchar, "_00%x", (unsigned char) oldname[i]);
+          strcat (filename, hexchar);
+          free (hexchar);
+        }
+
+      /* Check if we are nearing boundaries.  */
+      if (strlen (filename) >= PATH_MAX - 20)
+        break;
     }
+
+  free (oldname);
 }
 
 /* As we can't look-up a (forward-referenced) nodes' html filename
