@@ -1,11 +1,11 @@
 /* xref.c -- cross references for Texinfo.
-   $Id: xref.c,v 1.9 2004/03/10 22:34:21 dirt Exp $
+   $Id: xref.c,v 1.4.2.1 2007/06/27 17:11:03 karl Exp $
 
-   Copyright (C) 2004 Free Software Foundation, Inc.
+   Copyright (C) 2004, 2007 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -49,7 +49,7 @@ add_xref_punctuation (void)
         add_char ('.');
       else if (next_char != ',' && next_char != '.')
         /* period and comma terminate xrefs, and nothing else.  Instead
-           of generating an Info references that can't be followed,
+           of generating an Info reference that can't be followed,
            though, just insert a period.  Not pretty, but functional.  */
         add_char ('.');
     }
@@ -142,7 +142,7 @@ cm_xref (int arg)
                   xml_insert_element_with_attribute (XREFNODENAME, START,
                                                      "linkend=\"%s\"", arg1_id);
                   free (arg1_id);
-                  execute_string (*arg3 ? arg3 : arg2);
+                  execute_string ("%s", *arg3 ? arg3 : arg2);
                   xml_insert_element (XREFNODENAME, END);
                 }
               else
@@ -172,30 +172,30 @@ cm_xref (int arg)
 
           xml_insert_element (XREF, START);
           xml_insert_element (XREFNODENAME, START);
-          execute_string (arg1);
+          execute_string ("%s", arg1);
           xml_insert_element (XREFNODENAME, END);
           if (*arg2)
             {
               xml_insert_element (XREFINFONAME, START);
-              execute_string (arg2);
+              execute_string ("%s", arg2);
               xml_insert_element (XREFINFONAME, END);
             }
           if (*arg3)
             {
               xml_insert_element (XREFPRINTEDDESC, START);
-              execute_string (arg3);
+              execute_string ("%s", arg3);
               xml_insert_element (XREFPRINTEDDESC, END);
             }
           if (*arg4)
             {
               xml_insert_element (XREFINFOFILE, START);
-              execute_string (arg4);
+              execute_string ("%s", arg4);
               xml_insert_element (XREFINFOFILE, END);
             }
           if (*arg5)
             {
               xml_insert_element (XREFPRINTEDNAME, START);
-              execute_string (arg5);
+              execute_string ("%s", arg5);
               xml_insert_element (XREFPRINTEDNAME, END);
             }
           xml_insert_element (XREF, END);
@@ -230,18 +230,28 @@ cm_xref (int arg)
                 ref_name = arg2;
 
               if (html)
-                {
-                  /* html fixxme: revisit this; external node name not
-                     much use to us with numbered nodes. */
+                { /* More to do eventually, down to Unicode
+                     Normalization Form C.  See the HTML Xref nodes in
+                     the manual.  */
+                  char *file_arg = arg4;
                   add_html_elt ("<a href=");
 
+                  {
+                    /* If there's a directory part, ignore it.  */
+                    char *p = strrchr (file_arg, '/');
+                    if (p)
+                      file_arg = p + 1;
+
                   /* If there's a dot, make it a NULL terminator, so the
                      extension does not get into the way.  */
-                  {
-                    char *p = strrchr (arg4 , '.');
+                    p = strrchr (file_arg , '.');
                     if (p != NULL)
                       *p = 0;
                   }
+                  
+                  if (! *file_arg)
+                warning (_("Empty file name for HTML cross reference in `%s'"),
+                           arg4);
 
                   /* Note that if we are splitting, and the referenced
                      tag is an anchor rather than a node, we will
@@ -251,9 +261,9 @@ cm_xref (int arg)
                      non-existent file.  cm_anchor, which see, deals
                      with that problem.  */
                   if (splitting)
-                    execute_string ("\"%s/", arg4);
+                    execute_string ("\"../%s/", file_arg);
                   else
-                    execute_string ("\"%s.html", arg4);
+                    execute_string ("\"%s.html", file_arg);
                   /* Do not collapse -- to -, etc., in references.  */
                   in_fixed_width_font++;
                   tem = expansion (arg1, 0); /* expand @-commands in node */
@@ -261,7 +271,7 @@ cm_xref (int arg)
                   add_anchor_name (tem, 1);
                   free (tem);
                   add_word ("\">");
-                  execute_string ("%s", ref_name);
+                  execute_string ("%s",ref_name);
                   add_word ("</a>");
                 }
               else
@@ -425,16 +435,16 @@ cm_inforef (int arg)
         {
           xml_insert_element (INFOREF, START);
           xml_insert_element (INFOREFNODENAME, START);
-          execute_string (node);
+          execute_string ("%s", node);
           xml_insert_element (INFOREFNODENAME, END);
           if (*pname)
             {
               xml_insert_element (INFOREFREFNAME, START);
-              execute_string (pname);
+              execute_string ("%s", pname);
               xml_insert_element (INFOREFREFNAME, END);
             }
           xml_insert_element (INFOREFINFONAME, START);
-          execute_string (file);
+          execute_string ("%s", file);
           xml_insert_element (INFOREFINFONAME, END);
 
           xml_insert_element (INFOREF, END);
@@ -487,29 +497,29 @@ cm_uref (int arg)
           xml_insert_element_with_attribute (UREF, START, "url=\"%s\"",
               text_expansion (url));
           if (*replacement)
-            execute_string (replacement);
+            execute_string ("%s", replacement);
           else if (*desc)
-            execute_string (desc);
+            execute_string ("%s", desc);
           else
-            execute_string (url);
+            execute_string ("%s", url);
           xml_insert_element (UREF, END);
         }
       else if (xml)
         {
           xml_insert_element (UREF, START);
           xml_insert_element (UREFURL, START);
-          execute_string (url);
+          execute_string ("%s", url);
           xml_insert_element (UREFURL, END);
           if (*desc)
             {
               xml_insert_element (UREFDESC, START);
-              execute_string (desc);
+              execute_string ("%s", desc);
               xml_insert_element (UREFDESC, END);
             }
           if (*replacement)
             {
               xml_insert_element (UREFREPLACEMENT, START);
-              execute_string (replacement);
+              execute_string ("%s", replacement);
               xml_insert_element (UREFREPLACEMENT, END);
             }
           xml_insert_element (UREF, END);
@@ -566,19 +576,19 @@ cm_email (int arg)
         {
           xml_insert_element_with_attribute (EMAIL, START, "url=\"mailto:%s\"", addr);
           if (*name)
-              execute_string (name);
+              execute_string ("%s", name);
           xml_insert_element (EMAIL, END);
         }
       else if (xml)
         {
           xml_insert_element (EMAIL, START);
           xml_insert_element (EMAILADDRESS, START);
-          execute_string (addr);
+          execute_string ("%s", addr);
           xml_insert_element (EMAILADDRESS, END);
           if (*name)
             {
               xml_insert_element (EMAILNAME, START);
-              execute_string (name);
+              execute_string ("%s", name);
               xml_insert_element (EMAILNAME, END);
             }
           xml_insert_element (EMAIL, END);
